@@ -197,6 +197,8 @@ class Interpreter:
         elif var.isConst:
             raise exceptions.RuntimeError(f'Illegal assignment to a constant ({instruction.Variable}).', instruction.Token.Location, self.filename)
         value = self.InterpretExpression(instruction.Value, scope)
+        if value.Type == types.VariableTypes.Nil and value.Value != types.VariableTypes.Nil:
+            raise exceptions.RuntimeError(f'Value type is nil, but value is not. ({instruction.Variable}).', instruction.Token.Location, self.filename)
         if instruction.VarIndex is not None:
             return self.InterpretAssignToIndexedVar(var, instruction.VarIndex, value, scope)
         if instruction.Operator.Lexeme == '=':
@@ -987,6 +989,8 @@ class Interpreter:
         if var is None:
             return None
         if expr.Left is None:
+            if var.Value.Value != types.VariableTypes.Nil and var.Value.Type == types.VariableTypes.Nil:
+                raise exceptions.RuntimeError(f'Eval Into Var, val.Value is not nil, val.Type is nil. ({var.Name}).', expr.Token.Location, self.filename)
             return var.Value
         if expr.Left.ExprType == types.ExprTypes.VariableIndex:
             return self.EvaluateDatafieldIndexedVariable(var, expr.Left, rec, scope)
@@ -1027,8 +1031,8 @@ class Interpreter:
                 val = val.Value[i.Value]
         if expr.Right is not None and expr.Right.ExprType == types.ExprTypes.NewArrayIndex:
             raise exceptions.RuntimeError(f'Append not supported. ({var.Name}{index_as_str}).', ind.Token.Location, self.filename)
-        print("Indexed")
-        print("val: ", val.Type, " ", val.Value)
+        if val.Value != types.VariableTypes.Nil and val.Type == types.VariableTypes.Nil:
+            raise exceptions.RuntimeError(f'EvalIndexed, val.Value is not nil, val.Type is nil. ({var.Name}{index_as_str}).', ind.Token.Location, self.filename)
         return val
 
 
